import lotus.domino.*;

public class Utilities {

	// Class fields, shared by all objects.

	private static Session session;  
	private static Log notesLog = null;		
	private static String logDbPath = "";  
	private static String logName = "";  
	private static int logLevel;  

	// Constructor
	Utilities () {
	}
		    
	// Hold Notes session info so all objects can share it.
	public void setSession (Session s) {
		session = s;
		}
	public Session getSession () {
		return(session);
		}

	// Return the Notes log, or start a new one.
	public Log getNotesLog () throws NotesException {
		if (notesLog != null)
				return(notesLog);
		else {
			notesLog = session.createLog(logName);
			if (notesLog==null) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not create NotesLog object in NotesSession.");
			notesLog.openNotesLog(Constants.LOG_SERVER, logDbPath);
			return(notesLog);
			}
		}

	// Get all program parameters, storing them in class variables here.
	public void readParameters() throws NotesException{
			
		Database configDb;
		View configView = null;
		Document configDoc = null;
		String configDbPath = "";
		String logLevelString = "";  
			
		// Get the Notes.ini variable that holds the filename of the configuration database.
		configDbPath = session.getEnvironmentString(Constants.CONFIG_DB_INI, false); // not system var, add $

		// If the INI is not found, use the default path for the config db.
		if (configDbPath.compareTo("")==0) configDbPath = Constants.CONFIG_DB_DEFAULT;

		// Open the config db.
		configDb = session.getDatabase(Constants.CONFIG_SERVER, configDbPath); 
		if (!(configDb.isOpen())) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not open configuration database " + configDbPath + ".");
			
		// Open the view of configuration documents.
		configView = configDb.getView(Constants.CONFIG_VIEW); 
		if (configView == null) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not open view " + Constants.CONFIG_VIEW + " in the configuration database " + configDbPath + ".");

		// Get the configurations that relates to logging.

		configDoc = configView.getDocumentByKey(Constants.CONFIG_LOOKUP_LOGDB);
		if (configDoc == null) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGDB + " in the configuration database " + configDbPath + ".");
		logDbPath = configDoc.getItemValueString(Constants.CONFIG_VALUE_FIELD);
		if (logDbPath.compareTo("")==0) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGDB + " in the configuration database " + configDbPath + ".");
		if (configDoc!=null) configDoc.recycle();

		configDoc = configView.getDocumentByKey(Constants.CONFIG_LOOKUP_LOGNAME);
		if (configDoc == null) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGNAME + " in the configuration database " + configDbPath + ".");
		logName = configDoc.getItemValueString(Constants.CONFIG_VALUE_FIELD);
		if (logName.compareTo("")==0) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGNAME + " in the configuration database " + configDbPath + ".");
		if (configDoc!=null) configDoc.recycle();

		configDoc = configView.getDocumentByKey(Constants.CONFIG_LOOKUP_LOGLEVEL);
		if (configDoc == null) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGLEVEL + " in the configuration database " + configDbPath + ".");
		logLevelString = configDoc.getItemValueString(Constants.CONFIG_VALUE_FIELD);
		if (logLevelString.compareTo("")==0) throw new NotesException(NotesError.NOTES_ERR_ERROR, "Could not find the setting " + Constants.CONFIG_LOOKUP_LOGLEVEL + " in the configuration database " + configDbPath + ".");
		if (configDoc!=null) configDoc.recycle();

		// Change the logging level to a number.
		if (logLevelString.compareToIgnoreCase(Constants.LOG_LEVEL_ERROR_STRING)==0) 
			logLevel = Constants.LOG_LEVEL_ERROR;
		else if (logLevelString.compareToIgnoreCase(Constants.LOG_LEVEL_BRIEF_STRING)==0) 
			logLevel = Constants.LOG_LEVEL_BRIEF;
		else if (logLevelString.compareToIgnoreCase(Constants.LOG_LEVEL_FULL_STRING)==0) 
			logLevel = Constants.LOG_LEVEL_FULL;
		else
			logLevel = Constants.LOG_LEVEL_ERROR;

			
		// ***** Get other setup parameters here. *********
			
			
		// Clean up.
		if (configDoc!=null) configDoc.recycle();
		if (configView!=null) configView.recycle();
		if (configDb!=null) configDb.recycle();
		
		} // readParameters()

		
	// Simple getItems() for configuration. Some settings don't need a get(), if it is only used
	// within this class to define a larger parameter.
		
	public int getLogLevel () {
		return(logLevel);
		}

	// ***** Add getItems() for other setup parameters here. *********

		
}

